@@ -174,6 +174,8 @@ class HttpSession(requests.Session):
 
         # set stream to True, in order to get client/server IP/Port
         kwargs["stream"] = True
+        if kwargs["data"].strip().startswith("<xml>") and kwargs["data"].strip().endswith("</xml>"):
+            kwargs["data"]=str(kwargs["data"]).encode("utf-8").decode("latin1")
 
         start_timestamp = time.time()
         response = self._send_request_safe_mode(method, url, **kwargs)
